@@ -162,6 +162,8 @@ static const Resolutions g_vaResolutions = {
 static const BitMasks g_vaRTFormats = {
     VA_RT_FORMAT_YUV420, VA_RT_FORMAT_YUV422, VA_RT_FORMAT_YUV444,
     VA_RT_FORMAT_YUV411, VA_RT_FORMAT_YUV400, VA_RT_FORMAT_YUV420_10BPP,
+    VA_RT_FORMAT_YUV422_10, VA_RT_FORMAT_YUV444_10, VA_RT_FORMAT_YUV420_12,
+    VA_RT_FORMAT_YUV422_12, VA_RT_FORMAT_YUV444_12,
     VA_RT_FORMAT_RGB16, VA_RT_FORMAT_RGB32, VA_RT_FORMAT_RGBP,
     VA_RT_FORMAT_RGB32_10BPP, VA_RT_FORMAT_PROTECTED,
 };
